#!/bin/bash
#set -x

######## ANSIBLE VAULT PASSWORD ######
ansible_vault_render_pass () {
ANSIBLE_VAULT_TMP=${CI_ENVIRONMENT_NAME^^}_SECRET_DEPLOY_KEY
ANSIBLE_VAULT_PASS=$(echo ${!ANSIBLE_VAULT_TMP} | base64 -d)
if [ ! -z ${ANSIBLE_VAULT_PASS} ]
then
  echo ${ANSIBLE_VAULT_PASS} > /deploy/ansible_vault_password
  unset ANSIBLE_VAULT_PASS
  export ANSIBLE_VAULT_PASSWORD_FILE="/deploy/ansible_vault_password"
else
  echo -e "\nDeploy key for environment ${CI_ENVIRONMENT_NAME} not found...!";
  exit 1;
fi
}

######## VAULT PROCESSING ########
# Default variables secret when not set
vault_get_values () {
  VAULT_TOKEN_SECRET="/opt/kubernetes/vault_token_secret"
  VAULT_TOKEN_FILE="/deploy/vault_token"
{
  VAULT_ADDR_INIT_STATUS=$(curl -s --connect-timeout 10 ${VAULT_ADDR}/v1/sys/health | jq '.initialized')
 } || {
  echo -e "\nGet vault init status fail ...!";
  exit 1;
 }

 {
  VAULT_ADDR_SEALED_STATUS=$(curl -s --connect-timeout 10 ${VAULT_ADDR}/v1/sys/health | jq '.sealed')
 } || {
  echo -e "\nGet vault seal status fail ...!";
  exit 1;
 }

  # Healthcheck vault server
  if [ ! -z ${VAULT_ADDR_INIT_STATUS} ] && [ ${VAULT_ADDR_INIT_STATUS} == "true" ] && [ ! -z ${VAULT_ADDR_SEALED_STATUS} ] && [ ${VAULT_ADDR_SEALED_STATUS} == "false" ]
  then
    HEALTHCHECK_VAULT_ADDR="OK"
  else
    echo -e "\nHealthcheck vault server fail ...!";
    exit 1;
  fi

  if [ -f ${VAULT_TOKEN_SECRET} ]; then
    cp ${VAULT_TOKEN_SECRET} ${VAULT_TOKEN_FILE}
    chmod 600 ${VAULT_TOKEN_FILE}
    ansible-vault decrypt ${VAULT_TOKEN_FILE} > /dev/null
    export VAULT_TOKEN="$(cat ${VAULT_TOKEN_FILE})"
    rm -rf ${VAULT_TOKEN_FILE};
  fi

  if [ ${HEALTHCHECK_VAULT_ADDR} == "OK" ] && [ ! -z ${VAULT_TOKEN} ] && [ ! -z ${VAULT_PATH_SECRET} ]
  then
    DOCKER_VARIABLES=`/usr/local/bin/vault kv get -format=json ${VAULT_PATH_SECRET} | jq -r '.data.data | to_entries | .[] | .key + "=\"" + .value + "\""' | base64 | tr -d '\n'`
    unset VAULT_TOKEN;
  fi

  if [ -z ${DOCKER_VARIABLES} ]
  then
    echo -e "\nHave error when get value of file .env.\nPlease check vault config again ...!";
    exit 1;
  fi
}

# Main process

mkdir -p /deploy

# Render ansible vault pass
# Call function ansible_vault_render_pass
ansible_vault_render_pass

# If exist vault config env will get value
# Get secret from env
VAULT_PATH_SECRET_VARIABLE=${CI_ENVIRONMENT_NAME^^}_VAULT_PATH_SECRET
VAULT_PATH_SECRET=${!VAULT_PATH_SECRET_VARIABLE}

if [ ! -z ${VAULT_ADDR} ] && [ ! -z ${VAULT_PATH_SECRET} ]
then
  # Call function vault_get_values
  vault_get_values
fi

echo $DOCKER_VARIABLES | base64 -d > .env
